/*
 * this code snippet is adapted from a web page I found
 * it is identical except for cleanups, and a final XOR with 0xffff
 * as outlined in the uecp spec
 *
 * XMODEM    x^16 + x^12 + x^5 + 1
 */

#include <glib.h>

#define POLY       0x1021
#define CRC_INIT   0xFFFF

typedef guint16     CRC_TYPE;

/* declare this function as
 * extern guint16 ccitt_crc (const unsigned char *ptr, register int len);
 */

CRC_TYPE
ccitt_crc (const unsigned char *ptr, register int len)
{
	static int initialized = 0;
	static CRC_TYPE crc_register, crc_table[256];
	unsigned long i, j, k;

	if (!initialized)
	{
		for (i = 0; i < 256; i++)
		{
			j = i << 8;
			for(k = 8; k--; )
			{
				j = j & 0x8000? (j << 1) ^ POLY : j << 1;
			}

			crc_table[i] = (CRC_TYPE) j;

		}
		initialized = 1;
	}

	crc_register = CRC_INIT;     /* always init register */

	/* calc CRC */

	for ( ;len--; )
	{
		crc_register = (CRC_TYPE) ((crc_register << 8) ^
                           crc_table[((crc_register >> 8) & 0x00ff) ^ *ptr++]);
	}
	return (0xffff ^ crc_register);
}
