
/* messager.h - render specific UECP messages to a buffer
 *
 * Copyright (C) Thomas Vander Stichele
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LIBUECP_MESSAGER_H
#define LIBUECP_MESSAGER_H

/* enum for Message Element Code */
typedef enum
{
	UECP_MEC_PS = 2,
	UECP_MEC_TA_TP = 3,
	UECP_MEC_RT = 0x0a
} UecpMessageElementCode;

/* length of PS */
#define UECP_PS_SIZE 8

/* length of RT */
#define UECP_RT_SIZE 64

typedef struct _UecpMessager UecpMessager;

/* we use this struct to send out messages to a specific destination
 * (site/encoder address pair) and housekeep SQC's */
struct _UecpMessager
{
	unsigned int		site_address;		/* 10 bit */
	unsigned char		encoder_address;	/* 6 bit */
	unsigned char		sequence_counter;
	/* used for those messages that need it */
	unsigned char		data_set_number;
	unsigned char		program_service_number;
};

UecpMessager *	uecp_messager_new		();
void		uecp_messager_reset		(UecpMessager *messager);
void		uecp_messager_dispose		(UecpMessager *messager);

#define		uecp_messager_set_site_address(messager,address) \
		messager->site_address = address
#define		uecp_messager_set_encoder_address(messager,address) \
		messager->encoder_address = address
#define		uecp_messager_set_sequence_counter(messager,counter) \
		messager->sequence_counter = counter
#define		uecp_messager_set_data_set_number(messager,number) \
		messager->data_set_number = number
#define		uecp_messager_set_program_service_number(messager,number) \
		messager->program_service_number = number

/* specific functions */
guchar *	uecp_messager_ps		(UecpMessager *messager,
						 const guchar *ps);
guchar *	uecp_messager_ta_tp		(UecpMessager *messager,
						 gboolean ta, gboolean tp);
guchar *	uecp_messager_rt		(UecpMessager *messager,
						 const guchar *rt,
						 gboolean add, guchar number,
						 gboolean toggle);

#endif /* LIBUECP_MESSAGER_H */

