/* File : UECP.i */
%module UECP
%{
#include <glib.h>
#include <libuecp/libuecp.h>
%}

#include <libuecp/messager.h>

/* initialize glib's memory routines to use standard malloc */
%init %{
{
#include <glib.h>

  GMemVTable table;

  table.malloc = malloc;
  table.realloc = realloc;
  table.free = free;
  table.calloc = calloc;
  table.try_malloc = NULL;
  table.try_realloc = NULL;
  g_mem_set_vtable (&table);
}
%}


/* convert Perl scalars to gboolean * C arguments */
%typemap(perl5,in) gboolean *
{
  int value;

  value = (int) SvIV ($source);
  $target = g_malloc (sizeof (gboolean));
  if (value == 0)
    *$target = FALSE;
  else
    *$target = TRUE;
  /* FIXME: delete this boolean somewhere */
}

/* convert Perl scalars to const guchar * C arguments */
%typemap(perl5,in) const guchar *
{
  $target = (unsigned char *) SvPV ($source, na);
}

/* convert guchar * return values to Perl scalars */
%typemap(perl5,out) guchar *
{
  int len = 0;
  guchar *ptr = $source;

  /* calculate length of returned block based on the terminating 0xfe */

  while (*ptr != 0xff)
  {
    ++ptr;
    ++len;
  }
  ++len;

  /* copied from chapter 8 of the manual, sample char * return implementation */
  $target = sv_newmortal (); 
  sv_setpvn ($target, $source, len);
  argvi++;
}

/* rename all these functions so they drop the uecp prefix */
%rename uecp_messager_new 			messager_new;
%rename uecp_messager_reset 			messager_reset;
%rename uecp_messager_dispose 			messager_dispose;

%rename uecp_messager_set_site_address 		messager_set_site_address;
%rename uecp_messager_set_encoder_address 	messager_set_encoder_address;
%rename uecp_messager_set_sequence_counter 	messager_set_sequence_counter;
%rename uecp_messager_set_data_set_number 	messager_set_data_set_number;
%rename uecp_messager_set_program_service_number 	messager_set_program_service_number;

%rename uecp_messager_ps 			messager_ps;
%rename uecp_messager_ta_tp 			messager_ta_tp;
%rename uecp_messager_rt 			messager_rt;

/* functions to wrap */
UecpMessager *
	uecp_messager_new               ();
void    uecp_messager_reset             (UecpMessager *messager);
void    uecp_messager_dispose           (UecpMessager *messager);

void    uecp_messager_set_site_address 	(UecpMessager *messager, int address);
void    uecp_messager_set_encoder_address (UecpMessager *messager, int address);
void    uecp_messager_set_sequence_counter (UecpMessager *messager, int sqc);
void    uecp_messager_set_data_set_number (UecpMessager *messager, int dsn);
void    uecp_messager_set_program_service_number (UecpMessager *messager, int psn);

guchar *uecp_messager_ps                (UecpMessager *messager,
					 const guchar *ps);
guchar *uecp_messager_ta_tp             (UecpMessager *messager,
					 gboolean ta, gboolean tp);
guchar *uecp_messager_rt             	(UecpMessager *messager,
					 const guchar *rt, gboolean add,
					 int number, gboolean toggle);

