#include <glib.h>
#include <libuecp/libuecp.h>

static void
dump_buffer (const unsigned char *ptr)
{
	unsigned char *p;
	printf ("Dumping buffer %p, starting with %2x\n", ptr, *ptr);
	for (p = (unsigned char *) ptr; *p != 0xff; ++p)
	{
		printf ("%2x  ", *p);
	}
	printf ("%2x  \n", *p);

}

int
main (int argc, char *argv[])
{
	UecpFrame *frame;
	UecpElement *element;
	unsigned char *buffer;
	unsigned char *ps;
	unsigned char *tatp;

	frame = uecp_frame_new ();

	/* example 1 */
	uecp_frame_set_site_address (frame, 1023);
	uecp_frame_set_encoder_address (frame, 3);

	uecp_frame_set_sequence_counter (frame, 1);
	buffer = uecp_frame_render (frame);

	dump_buffer (buffer);
	g_free (buffer);

	/* example 2; including a message */
	g_print ("setting PS to 'UECP    ' through element\n");
	uecp_frame_set_sequence_counter (frame, 2);
	element = uecp_element_new ();
	ps = g_strdup_printf ("UECP    ");
	if (!uecp_element_set (element, 2, 0, 0, -1, strlen (ps), ps))
		g_print ("ERROR: could not set element values\n");
	if (!uecp_frame_add_element (frame, element))
		g_print ("ERROR: could not add element to frame\n");
	buffer = uecp_frame_render (frame);

	dump_buffer (buffer);
	g_free (buffer);
	uecp_frame_reset (frame);

	/* example 3; including two messages in a row */
	uecp_frame_set_site_address (frame, 1023);
	uecp_frame_set_encoder_address (frame, 3);
	uecp_frame_set_sequence_counter (frame, 3);

	g_print ("setting PS to 'UECP    ', and TA and TP, through element\n");
	element = uecp_element_new ();
	ps = g_strdup_printf ("UECP    ");
	if (!uecp_element_set (element, 2, 0, 0, -1, strlen (ps), ps))
		g_print ("ERROR: could not set element values\n");
	if (!uecp_frame_add_element (frame, element))
		g_print ("ERROR: could not add element to frame\n");

	element = uecp_element_new ();
	tatp = (unsigned char *) g_malloc (1);
	*tatp = 1 + 2; /* TA & TP both on */
	if (!uecp_element_set (element, 3, 0, 0, -1, 1, tatp))
		g_print ("ERROR: could not set element values\n");
	if (!uecp_frame_add_element (frame, element))
		g_print ("ERROR: could not add element to frame\n");
	buffer = uecp_frame_render (frame);

	dump_buffer (buffer);
	g_free (buffer);

	uecp_frame_dispose (frame);

	return 0;
}
